@@ -380,6 +380,27 @@ def group_by_function(
     return list(ret.values())
 
 
+def group_by_function_ordered(
+    lst: VyList, function: types.FunctionType, ctx: Context
+) -> LazyList:
+    """Group a list of elements by a function, but order is preserved"""
+
+    ret = []
+    is_lst = isinstance(lst, LazyList) or isinstance(lst, list)
+    for el in lst:
+        k = safe_apply(function, el, ctx=ctx)
+        if ret == []:
+            ret.append([k, [el] if is_lst else el])
+        elif ret[-1][0] == k:
+            if is_lst:
+                ret[-1][1].append(el)
+            else:
+                ret[-1][1] += el
+        else:
+            ret.append([k, [el] if is_lst else el])
+    return [x[1] for x in ret]
+
+
 def has_ind(lst: VyList, ind: int) -> bool:
     """Whether or not the list is long enough for that index"""
     if isinstance(lst, LazyList):
